@@ -16,6 +16,7 @@ pub enum ErrorKind {
     InvalidUnaryOperand(Variant),  // unsupported operand for type
     InvalidBinaryOperand(Variant, Variant),
     OverflowError,
+    DivideByZero,
     NegativeShiftCount,
     NameNotDefined(String),
     CantAssignImmutable,  // can't assign to immutable global variable
@@ -49,12 +50,12 @@ impl RuntimeError {
         self.cause.replace(Box::new(cause)); self
     }
     
-    pub fn insert_trace(mut self, trace: impl Iterator<Item=TraceSite>) -> Self {
-        self.traceback.splice(0..0, trace); self
+    pub fn extend_trace(mut self, trace: impl Iterator<Item=TraceSite>) -> Self {
+        self.traceback.extend(trace); self
     }
     
-    pub fn insert_site(mut self, site: TraceSite) -> Self {
-        self.traceback.insert(0, site); self
+    pub fn push_frame(mut self, site: TraceSite) -> Self {
+        self.traceback.push(site); self
     }
     
     pub fn kind(&self) -> &ErrorKind { &self.kind }
@@ -77,6 +78,7 @@ impl fmt::Display for RuntimeError {
             // TODO
             ErrorKind::InvalidUnaryOperand(..) => format!("unsupported operand for type '...'"),
             ErrorKind::InvalidBinaryOperand(..) => format!("unsupported operand for type '...' and '...'"),
+            ErrorKind::DivideByZero => format!("divide by zero"),
             ErrorKind::OverflowError => format!("integer arithmetic overflow"),
             ErrorKind::NegativeShiftCount => format!("negative bitshift count"),
             ErrorKind::NameNotDefined(name) => format!("undefined variable \"{}\"", name),
@@ -89,7 +91,7 @@ impl fmt::Display for RuntimeError {
             ErrorKind::Other => String::new(),
         };
         
-        utils::format_error(fmt, "runtime error", Some(message.as_str()), self.source())
+        utils::format_error(fmt, "Runtime error", Some(message.as_str()), self.source())
     }
 }
 
