@@ -1,7 +1,8 @@
 use std::fmt;
 use std::rc::Rc;
 use std::ops::Deref;
-use std::ptr::NonNull;
+use std::ptr::{self, NonNull};
+use std::hash::{Hash, Hasher};
 use std::marker::PhantomData;
 
 use crate::runtime::gc::{GCBox, GCArray, GC_STATE, deref_safe, GCTrace};
@@ -24,8 +25,8 @@ impl<T> GC<T> where T: GCTrace + ?Sized {
         unsafe { &*self.ptr.as_ptr() }
     }
     
-    pub fn ptr_eq(self: &GC<T>, other: &GC<T>) -> bool {
-        unimplemented!()
+    pub fn ptr_eq(self_gc: &GC<T>, other_gc: &GC<T>) -> bool {
+        self_gc.inner().ptr_eq(other_gc.inner())
     }
 }
 
@@ -38,12 +39,29 @@ impl<T: GCTrace> GC<T> {
     }
 }
 
+impl<T> From<GC<T>> for GC<dyn GCTrace> where T: GCTrace {
+    fn from(handle: GC<T>) -> Self {
+        Self {
+            ptr: handle.ptr,
+            _marker: PhantomData,
+        }
+    }
+}
+
 // impl<T> From<Box<T>> for GC<T> where T: ?Sized {
 //     fn from(data: Box<T>) -> Self {
 //         unimplemented!()
 //     }
 // }
 
+impl<T> Deref for GC<T> where T: GCTrace + ?Sized {
+    type Target = T;
+    
+    #[inline]
+    fn deref(&self) -> &Self::Target {
+        self.inner().value()
+    }
+}
 
 impl<T> Clone for GC<T> where T: GCTrace + ?Sized {
     fn clone(&self) -> Self {
@@ -56,16 +74,13 @@ impl<T> Clone for GC<T> where T: GCTrace + ?Sized {
 
 impl<T> Copy for GC<T> where T: GCTrace + ?Sized { }
 
-
-impl<T> Deref for GC<T> where T: GCTrace + ?Sized {
-    type Target = T;
-    
-    #[inline]
-    fn deref(&self) -> &Self::Target {
-        self.inner().value()
+impl<T> Hash for GC<T> where T: GCTrace {
+    fn hash<H>(&self, state: &mut H) where H: Hasher {
+        <NonNull<GCBox<T>> as Hash>::hash(&self.ptr, state)
     }
 }
 
+
 impl<T> fmt::Debug for GC<T> where T: GCTrace + ?Sized {
     fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         if fmt.alternate() {
